===============================
Next Generation Nexus Generator
===============================


.. image:: https://img.shields.io/pypi/v/nexgen.svg
        :target: https://pypi.python.org/pypi/nexgen
        :alt: PyPI release

.. image:: https://img.shields.io/pypi/pyversions/nexgen.svg
        :target: https://pypi.python.org/pypi/nexgen
        :alt: Supported Python versions

.. image:: https://img.shields.io/lgtm/alerts/g/dials/nexgen.svg?logo=lgtm&logoWidth=18
        :target: https://lgtm.com/projects/g/dials/nexgen/alerts/
        :alt: Total alerts

.. image:: https://readthedocs.org/projects/nexgen/badge/?version=latest
        :target: https://nexgen.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://codecov.io/gh/dials/nexgen/branch/main/graph/badge.svg
        :target: https://codecov.io/gh/dials/nexgen
        :alt: Test coverage

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
        :target: https://github.com/ambv/black
        :alt: Code style: black


* Free software: BSD license
* Documentation: https://nexgen.readthedocs.io.

This package provides tools to generate Nexus files.

